local addonName, addon = ...
local LSM = LibStub("LibSharedMedia-3.0")

addon.L = addon.L or {} --setup localization
local L = setmetatable(addon.L, {__index = function(t,i) return i end} )

local defaults = {
	profile = {
		enabled = true,
		inCombatOnly = true,
		font = "Friz Quadrata TT",
		fontSize = 15,
		outline = false,
		justifyH = "Center",
		anchorFrame = "Center",
		anchorParent = "Center",
		xOffset = 0,
		yOffset = 0,
		color = {r = 1, g = 0, b = 0, a = 1},
	},
}

local optionsTable = {
    name = addonName,
    handler = addon,
    type = 'group',
    args = {
		options = {
			name = L['Options'],
			desc = L['Setup options here.'],
			type = 'group',
			order = 1,
			args = {
				enable = {
					name = L['Enable'],
					desc = L['Enable/disable the addon.'],
					type = 'toggle',
					order = 1,
					set = function(_, enabled)
						addon.db.profile.enabled = enabled
						if enabled then
							addon:Enable()
						else
							addon:Disable()
						end
					end,
					get = function()
						return addon.db.profile.enabled
					end,
				},
				inCombatOnly = {
					name = L['In Combat Only'],
					desc = L['Display only while in combat.'],
					type = 'toggle',
					order = 2,
					set = function(_, enabled)
						addon.db.profile.inCombatOnly = enabled
						if not enabled then
							addon.combatFrame:Show()
						else
							if InCombatLockdown() then
								addon.combatFrame:Show()
							else
								addon.combatFrame:Hide()
							end
						end
					end,
					get = function()
						return addon.db.profile.inCombatOnly
					end,
				},
				fontHeader = {
					type = 'header',
					order = 3,
					name = L['Font Settings'],
				},
				font = {
					type = 'select',
					order = 4,
					dialogControl = 'LSM30_Font',
					name = L['Font'],
					desc = L['Select a font.'],
					values = LSM:HashTable("font"),
					set = function(self,key)
						addon.db.profile.font = key
						addon:ApplyAllOptions()
					end,
					get = function()
						return addon.db.profile.font
					end,
				},
				outline = {
					type = 'toggle',
					order = 5,
					name = L['Outline'],
					desc = L[''],
					set = function(_, enabled)
						addon.db.profile.outline = enabled
						addon:ApplyAllOptions()
					end,
					get = function()
						return addon.db.profile.outline
					end,
				},
				fontSize = {
					type = 'input',
					order = 6,
					name = L['Font Size'],
					desc = L['Set the font size.'],
					set = function(_, value)
						addon.db.profile.fontSize = tonumber(value)
						addon:ApplyAllOptions()
					end,
					get = function() 
						return tostring(addon.db.profile.fontSize)
					end,
				},
				justifyH = {
					type = 'select',
					order = 7,
					name = L["Justify"],
					desc = L['Horizontal Justification'],
					values = {
						Center = "Center",
						Left = "Left",
						Right = "Right",
					},
					set = function(self, key)
						addon.db.profile.justifyH = key
						addon:ApplyAllOptions()
					end,
					get = function() 
						return addon.db.profile.justifyH
					end,
				},
				color = {
					type = 'color',
					order = 8,
					name = L['Font Color'],
					desc = L['Set the color of the font.'],
					hasAlpha = true,
					set = function (_, r, g, b, a)
						addon.db.profile.color.r = r
						addon.db.profile.color.g = g
						addon.db.profile.color.b = b
						addon.db.profile.color.a = a
						addon:ApplyAllOptions()
					end,
					get = function()
						return
							addon.db.profile.color.r,
							addon.db.profile.color.g,
							addon.db.profile.color.b,
							addon.db.profile.color.a
					end,
				},
				positionHeader = {
					type = 'header',
					order = 9,
					name = L['Position Settings'],
				},
				anchorFrame = {
					type = 'select',
					order = 10,
					name = L["Anchor:"],
					desc = L[''],
					values = {
						Center = "Center",
						Top = "Top",
						Bottom = "Bottom",
						Left = "Left",
						Right = "Right",
						TopLeft = "Top Left",
						TopRight = "Top Right",
						BottomLeft = "Bottom Left",
						BottomRight = "Bottom Right",
					},
					set = function(self, key)
						addon.db.profile.anchorFrame = key
						addon:ApplyAllOptions()
					end,
					get = function() 
						return addon.db.profile.anchorFrame
					end,
				},
				anchorParent = {
					type = 'select',
					order = 11,
					name = L["To Screen's:"],
					desc = L[''],
					values = {
						Center = "Center",
						Top = "Top",
						Bottom = "Bottom",
						Left = "Left",
						Right = "Right",
						TopLeft = "Top Left",
						TopRight = "Top Right",
						BottomLeft = "Bottom Left",
						BottomRight = "Bottom Right",
					},
					set = function(self, key)
						addon.db.profile.anchorParent = key
						addon:ApplyAllOptions()
					end,
					get = function() 
						return addon.db.profile.anchorParent
					end,
				},
				xOffset = {
					type = 'input',
					order = 12,
					name = L['Horizontal Offset'],
					desc = L['Set the horizontal position of the display.'],
					set = function(_, value)
						addon.db.profile.xOffset = tonumber(value)
						addon:ApplyAllOptions()
					end,
					get = function() 
						return tostring(addon.db.profile.xOffset)
					end,
				},
				yOffset = {
					type = 'input',
					order = 13,
					name = L['Vertical Offset'],
					desc = L['Set the vertical position of the display.'],
					set = function(_, value)
						addon.db.profile.yOffset = tonumber(value)
						addon:ApplyAllOptions()
					end,
					get = function() 
						return tostring(addon.db.profile.yOffset)
					end,
				},
			},
		},
    },
}

function addon:SetupConfig()
	self.db = LibStub("AceDB-3.0"):New("ShieldBarrierTrackerDB", defaults)
	
	optionsTable.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db) --add profile GUI
	self.db.RegisterCallback(self, "OnProfileChanged", "ApplyAllOptions")
	self.db.RegisterCallback(self, "OnProfileCopied", "ApplyAllOptions")
	self.db.RegisterCallback(self, "OnProfileReset", "ApplyAllOptions")
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable(addonName, optionsTable)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions(addonName)
end