local addonName, addon = ...
LibStub("AceAddon-3.0"):NewAddon(addon, addonName, "AceEvent-3.0")
local LSM = LibStub("LibSharedMedia-3.0")

local UnitStat = UnitStat
local UnitAttackPower = UnitAttackPower
local UnitPower = UnitPower

function addon:OnInitialize()
	self.combatFrame = CreateFrame("frame", nil, UIParent)
	self.displayFrame = CreateFrame("frame", nil, self.combatFrame)
	self.displayFrame.text = self.displayFrame:CreateFontString()
	self:SetupConfig()
	self:ApplyAllOptions()
end

function addon:OnEnable()
	self:RegisterEvent("UNIT_STATS")
	self:RegisterEvent("UNIT_ATTACK_POWER")
	self:RegisterEvent("UNIT_POWER")
	self:RegisterEvent("PLAYER_REGEN_ENABLED")
	self:RegisterEvent("PLAYER_REGEN_DISABLED")
	self:RegisterEvent("PLAYER_ENTERING_WORLD")
	if not InCombatLockdown() then
		self.combatFrame:Hide()
	end
	self.displayFrame:Show()
end

function addon:OnDisable()
	self.combatFrame:Hide()
	self.displayFrame:Hide()
end

function addon:ApplyAllOptions()
	self.displayFrame:ClearAllPoints()
	self.displayFrame:SetPoint(self.db.profile.anchorFrame, UIParent, self.db.profile.anchorParent, self.db.profile.xOffset, self.db.profile.yOffset)
	self.displayFrame:SetHeight(self.db.profile.fontSize)
	self.displayFrame:SetWidth(7 * self.db.profile.fontSize)
	self.displayFrame.text:SetAllPoints(self.displayFrame)
	self.displayFrame.text:SetJustifyH(self.db.profile.justifyH)
	self.displayFrame.text:SetFont(LSM:Fetch("font", self.db.profile.font), self.db.profile.fontSize, self.db.profile.outline and "Outline" or nil)
	local color = self.db.profile.color
	self.displayFrame.text:SetTextColor(color.r, color.g, color.b, color.a)
end

function addon:GetAttackPower(unit)
	local base, posBuff, negBuff = UnitAttackPower(unit)
	return base + posBuff + negBuff
end

function addon:UNIT_STATS(event, unit) --strength changed
	if unit ~= "player" then return end
	self.str = UnitStat("player", 1)
	self.stam = UnitStat("player", 3)
	self:UpdateDisplay()
end

function addon:UNIT_ATTACK_POWER(event, unit) --ap changed
	if unit ~= "player" then return end
	self.ap = self:GetAttackPower(unit)
	self:UpdateDisplay()
end

function addon:UNIT_POWER(event, unit, powerType) --rage changed
	if unit ~= "player" then return end
	if powerType ~= "RAGE" then return end
	self.rage = UnitPower("player", 1)
	self:UpdateDisplay()
end

function addon:PLAYER_REGEN_ENABLED()
	if self.db.profile.inCombatOnly then
		self.combatFrame:Hide()
	end
end

function addon:PLAYER_REGEN_DISABLED()
	self.combatFrame:Show()
end

function addon:PLAYER_ENTERING_WORLD() --get initial values for everything
	self.str = UnitStat("player", 1)
	self.stam = UnitStat("player", 3)
	self.ap = self:GetAttackPower("player")
	self.rage = UnitPower("player", 1)
	self:UpdateDisplay()
end

function addon:UpdateDisplay()
	self.barrier = floor(math.max(2 * (self.ap - 2 * self.str), math.min(math.max(self.rage, 20), 60) / 60 * self.stam * 2.5))
	self.displayFrame.text:SetText(self.barrier)
end